import { defaultLocale } from 'astro-i18n-aut';
import { ui, defaultLang, showDefaultLang } from './ui';

export function useTranslatedPath(lang: string) {
  return function translatePath(path: string, l: string = lang) {
    return !showDefaultLang && l === defaultLang ? path : `/${l}${path}`.replace(/\/$/g, '');
  }
}

export function useTranslations(lang: string) {
  return function t(key: keyof typeof ui[typeof defaultLang]) {
    return ui[lang as keyof typeof ui][key] || ui[defaultLang][key];
  }
}

export function parseSlug(id: string) {
  const splitPath = id.split('/');
  const split = splitPath.pop()?.split('.');
  const lang = split?.length === 2 ? defaultLocale : split?.[1];
  return [splitPath.join("/"), lang]
}

export function filterCollection<T extends { id: string }>(collection: T[], locale: string) {
  return collection.filter(post => {
    const [_, lang] = parseSlug(post?.id);
    return lang === locale;
  });
}
